package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````H"````````!``````````'BQ````
M`````````$``.``)`$``'0`<``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````,B@````````R*``````````
M`"````````$````&````B*L```````"(JR```````(BK(```````F`0`````
M```@%0``````````(````````@````8```"XJP```````+BK(```````N*L@
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````X)D```````#@F0```````."9````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````(BK````````B*L@``````"(JR``
M`````'@$````````>`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50"*L54!$TZ?($.K,NFU@AZ\)6R&V!$```!%````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!%````
M20```$T```!.````50```%8```!8````7````%T`````````7P```&(```!C
M````9```````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````)0$``!(`````
M````````````````````^P$``!(`````````````````````````>@(``!(`
M````````````````````````3P(``!(`````````````````````````$0``
M`"``````````````````````````@0(``!(`````````````````````````
M!@,``!(`````````````````````````R````!(`````````````````````
M````E@(``!(`````````````````````````EP$``!(`````````````````
M````````[@(``!(`````````````````````````Y@(``!(`````````````
M````````````F````!(`````````````````````````QP,``!(`````````
M````````````````(`$``!(`````````````````````````L@(``!(`````
M````````````````````I`(``!(`````````````````````````:0(``!(`
M````````````````````````_P(``!(`````````````````````````'`,`
M`!(`````````````````````````>P$``!(`````````````````````````
M20$``!(`````````````````````````U@```!(`````````````````````
M````Q0$``!(`````````````````````````*`(``!(`````````````````
M````````8`(``!(`````````````````````````.`(``!(`````````````
M````````````5P(``!(`````````````````````````L@$``!(`````````
M````````````````CP(``!(`````````````````````````]@$``!(`````
M````````````````````8`,``!(`````````````````````````60,``!(`
M````````````````````````5P$``!(`````````````````````````#P,`
M`!(`````````````````````````+0```"``````````````````````````
MQ@(``!(`````````````````````````>````!(`````````````````````
M````%`(``!(`````````````````````````O@$``!(`````````````````
M````````IP```!(`````````````````````````LP```!(`````````````
M````````````<`$``!(`````````````````````````-@$``!(`````````
M````````````````:@```!(`````````````````````````*@$``!(`````
M````````````````````S0(``!(`````````````````````````IP$``!(`
M````````````````````````!`$``!(`````````````````````````AP(`
M`!(`````````````````````````[P$``!(`````````````````````````
M2@,``!(`````````````````````````(P,``!(`````````````````````
M````B0$``!(`````````````````````````AP```!(`````````````````
M````````4@,``!(`````````````````````````G0(``!(`````````````
M````````````/````"``````````````````````````Z````!(`````````
M````````````````9P$``!(`````````````````````````VP(``!(`````
M````````````````````2@(``!(`````````````````````````#`(``!(`
M````````````````````````N`(``!(`````````````````````````4```
M`"``````````````````````````+0,``"(`````````````````````````
MJP(``!(`````````````````````````/`,``!(`````````````````````
M````T`,``!(`#@"`6````````'8`````````G@,``!(`#P"460``````````
M````````]0,``!(`#@!@2````````%0,````````;0,``!(`#@!P'@``````
M`"0"````````I`,``!(`#@#@0`````````4`````````8P0``!(`#@#P0```
M``````D"````````700``!(`"P"(&@``````````````````D`0``!(`#@#`
M5````````+D#````````@P,``!``&@`@L"``````````````````W`,``!(`
M#@``0P```````"0`````````#P0``!$`$`"@60````````0`````````T`$`
M`!$`%@"@JR```````!,`````````CP,``!``&@"HP"``````````````````
M6P0``!(`#@"0/P```````#``````````<`0``!(`#@#P1@```````&P!````
M````@@0``!(`#@!`1@```````'D``````````@0``!``&0``L"``````````
M````````Z0,``!(`#@`P0P```````.,`````````<@,``!$`&@!(L"``````
M``@`````````?`,``!``&0`@L"``````````````````<P,``"$`&@!(L"``
M``````@`````````1`0``!$`&0`8L"````````@`````````^`(``!$`&@!@
ML"````````@`````````E`,``!(`#@"060````````(`````````-`0``!(`
M#@`@60```````&4`````````"`0``!(`#@"@(````````"L`````````!`0`
M`"``&0``L"``````````````````%0$``!$`&@`@L"````````0`````````
M=`,``"$`&@!(L"````````@`````````M0,``!(`#@#`1@```````"0`````
M````'@0``!(`#@`00````````,$`````````]P```!$`&@!`L"````````$`
M````````3@0``!(`#@`@1````````!("`````````&QI8G!E<FPN<V\N-2XR
M-@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE
M=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!0
M3%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`7U]E
M<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO
M<V4`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?
M7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I
M<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`
M<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX
M<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI
M;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI
M>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD
M`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U
M<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?
M<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!'3$E"0U\R+C(N-0!'3$E"0U\R+C$T`$=,24)#7S(N,RXT`$=,24)#
M7S(N,RXR`$=,24)#7S(N-``````"``,``@`"`````@`"`````@````(``@``
M``(````"``(`!``"``(````````````#``(`!0`"`````@`#``(``@````8`
M```'`````P`"``````````````````8```````(``P`"``(```````(``@``
M```````"``(``P`&`````@`"``8``0`!``$``0`!``$``0`!``$``0`!````
M`0`!``$``0`!``$``@`!``(``0`"``$``0`!``$````"``$``0````$`````
M``$``0#?`0``$````"````!U&FD)```#`*8$`````````0`%`"X"```0````
M`````)21E@8```<`L@0``!````!T&6D)```&`+T$```0````<AEI"0``!0#)
M!```$````!1I:0T```0`U00``!````!U&FD)```"`*8$````````B*L@````
M```(`````````*`A````````D*L@```````(`````````&`A````````"+`@
M```````(``````````BP(```````&+`@```````(`````````.!<````````
MN*\@```````&````!0``````````````P*\@```````&````"@``````````
M````R*\@```````&````(```````````````T*\@```````&````)```````
M````````V*\@```````&````+```````````````X*\@```````&````-P``
M````````````Z*\@```````&````.@``````````````\*\@```````&````
M00``````````````^*\@```````&````0@``````````````H*L@```````%
M````4```````````````(+`@```````%````8```````````````0+`@````
M```%````9```````````````2+`@```````%````5P``````````````8+`@
M```````%````6P``````````````X*T@```````'`````0``````````````
MZ*T@```````'`````@``````````````\*T@```````'`````P``````````
M````^*T@```````'````!````````````````*X@```````'````!@``````
M````````"*X@```````'````!P``````````````$*X@```````'````"```
M````````````&*X@```````'````"0``````````````(*X@```````'````
M"P``````````````**X@```````'````#```````````````,*X@```````'
M````#0``````````````.*X@```````'````#@``````````````0*X@````
M```'````#P``````````````2*X@```````'````$```````````````4*X@
M```````'````$0``````````````6*X@```````'````$@``````````````
M8*X@```````'````$P``````````````:*X@```````'````%```````````
M````<*X@```````'````%0``````````````>*X@```````'````%@``````
M````````@*X@```````'````%P``````````````B*X@```````'````&```
M````````````D*X@```````'````&0``````````````F*X@```````'````
M&@``````````````H*X@```````'````&P``````````````J*X@```````'
M````'```````````````L*X@```````'````'0``````````````N*X@````
M```'````'@``````````````P*X@```````'````'P``````````````R*X@
M```````'````(0``````````````T*X@```````'````(@``````````````
MV*X@```````'````(P``````````````X*X@```````'````)0``````````
M````Z*X@```````'````)@``````````````\*X@```````'````)P``````
M````````^*X@```````'````*````````````````*\@```````'````*0``
M````````````"*\@```````'````*@``````````````$*\@```````'````
M*P``````````````&*\@```````'````+0``````````````(*\@```````'
M````+@``````````````**\@```````'````+P``````````````,*\@````
M```'````,```````````````.*\@```````'````,0``````````````0*\@
M```````'````,@``````````````2*\@```````'````,P``````````````
M4*\@```````'````-```````````````6*\@```````'````-0``````````
M````8*\@```````'````-@``````````````:*\@```````'````.```````
M````````<*\@```````'````.0``````````````>*\@```````'````.P``
M````````````@*\@```````'````/```````````````B*\@```````'````
M/0``````````````D*\@```````'````/@``````````````F*\@```````'
M````/P``````````````H*\@```````'````0```````````````J*\@````
M```'````0P``````````````L*\@```````'````1```````````````2(/L
M"$B+!3V5(`!(A<!T`O_02(/$",,`_S4JDR``_R4LDR``#Q]``/\E*I,@`&@`
M````Z>#_____)2*3(`!H`0```.G0_____R4:DR``:`(```#IP/____\E$I,@
M`&@#````Z;#_____)0J3(`!H!````.F@_____R4"DR``:`4```#ID/____\E
M^I(@`&@&````Z8#_____)?*2(`!H!P```.EP_____R7JDB``:`@```#I8/__
M__\EXI(@`&@)````Z5#_____)=J2(`!H"@```.E`_____R72DB``:`L```#I
M,/____\ERI(@`&@,````Z2#_____)<*2(`!H#0```.D0_____R6ZDB``:`X`
M``#I`/____\ELI(@`&@/````Z?#^____):J2(`!H$````.G@_O___R6BDB``
M:!$```#IT/[___\EFI(@`&@2````Z<#^____)9*2(`!H$P```.FP_O___R6*
MDB``:!0```#IH/[___\E@I(@`&@5````Z9#^____)7J2(`!H%@```.F`_O__
M_R5RDB``:!<```#I</[___\E:I(@`&@8````Z6#^____)6*2(`!H&0```.E0
M_O___R5:DB``:!H```#I0/[___\E4I(@`&@;````Z3#^____)4J2(`!H'```
M`.D@_O___R5"DB``:!T```#I$/[___\E.I(@`&@>````Z0#^____)3*2(`!H
M'P```.GP_?___R4JDB``:"````#IX/W___\E(I(@`&@A````Z=#]____)1J2
M(`!H(@```.G`_?___R42DB``:",```#IL/W___\E"I(@`&@D````Z:#]____
M)0*2(`!H)0```.F0_?___R7ZD2``:"8```#I@/W___\E\I$@`&@G````Z7#]
M____)>J1(`!H*````.E@_?___R7BD2``:"D```#I4/W___\EVI$@`&@J````
MZ4#]____)=*1(`!H*P```.DP_?___R7*D2``:"P```#I(/W___\EPI$@`&@M
M````Z1#]____);J1(`!H+@```.D`_?___R6RD2``:"\```#I\/S___\EJI$@
M`&@P````Z>#\____):*1(`!H,0```.G0_/___R6:D2``:#(```#IP/S___\E
MDI$@`&@S````Z;#\____)8J1(`!H-````.F@_/___R6"D2``:#4```#ID/S_
M__\E>I$@`&@V````Z8#\____)7*1(`!H-P```.EP_/___R5JD2``:#@```#I
M8/S___\E8I$@`&@Y````Z5#\____)5J1(`!H.@```.E`_/___R62D2``9I``
M`````````%532(/L.(E\)!Q(B70D$$B-?"0<2(E4)`A(C70D$$B-5"0(9$B+
M!"4H````2(E$)"@QP.@8_O__2(LU*9$@`$B+/2J1(`!(B?+H0CH``(`]>Y$@
M``!U+^@T_?__2(7`2(D%RJ$@``^$K@$``$B)Q^AL_/__BSTVD2``Z.']___&
M@-$(````BSTDD2``Z,_]__^`B*H$```"BST2D2``Z+W]__^`B*H$```!BT0D
M'(UX!4BX_________Q](8_](.<</AQD!``!(P><#2(T=6#P``.@)_?__2(M\
M)!!(B04UH2``O@4```#'!2ZA(``$````2(L72(E8"$B-'2T\``!(@\<(2(E8
M&$B)$$B+%9:0(`!(B5`0BU0D'(/Z`8U*!'X<9@\?1```3(L/3&/&@\8!2(/'
M"#G.3HE,P/AUZDB+/>N@(`!(8\E(C34!(```2,=$R/@`````@\(#13'`2(G!
MZ'K]__^%P(G#=%%(BSV]H"``2(UL)"3HX_O__TB-/4\Z```QP$B)[N@B&0``
M2(7`=#I(BSV6H"``Z&'[___H#/W__XG82(M<)"AD2#,<)2@```!U7TB#Q#A;
M7<-(BSULH"``Z+?]__^)P^N?2(L]5*`@`$B%_W0<Z#(X``#KLTB--4F+(`!(
MC3V5.0``,<#HF_S__TB-/8PY``!(B>[HK!@``$B%P$B)QTB)!1>@(`!T@.O$
MZ!;[__^_`0```.A\_?__9BX/'X0``````&:0,>U)B=%>2(GB2(/D\%!43(T%
MVC@``$B-#6,X``!(C3VL_?___Q7^CB``]`\?1```2(T]28\@`$B-!4F/(`!5
M2"GX2(GE2(/X#G852(L%QHX@`$B%P'0)7?_@9@\?1```7<,/'T``9BX/'X0`
M`````$B-/0F/(`!(C34"CR``54@I_DB)Y4C!_@-(B?!(P>@_2`'&2-'^=!A(
MBP6QCB``2(7`=`Q=_^!F#Q^$``````!=PP\?0`!F+@\?A```````@#T!CR``
M`'4G2(,]AXX@``!52(GE=`Q(BSV*CB``Z-W\___H2/___UW&!=B.(``!\\,/
M'T``9BX/'X0``````$B-/?&)(`!(@S\`=0OI7O___V8/'T0``$B+!2F.(`!(
MA<!TZ55(B>7_T%WI0/___T%7059,C4\X055!5#')55-(@>R8`@``9$B+!"4H
M````2(F$)(@"```QP$B)X@\?`$&+!`E-BP0)#\A,B<:)P$C![B!(B01*3(G`
M2<'H.$C!Z"@E`/\``$P)P$F)\$C!Y@A)P>`8@>8``/\`18G`3`G`2`GP2(E$
M2@A(@\$(2(/Y0'6M2(VR``(``&8/'T0``$B+0FA(,T)`2(/""$@S0@A(,T+X
M2(T,`$C!Z!]("<B#X/](B4)X2#GR==5,BP=,BU\@3(M/$$R+5QA(BW<(2(M,
M)`A,B<!,B<)-B<5(P>H;2,'@!4G![0)("=!(BQ0D2(GSB<!(P>,>28V,"IEY
M@EI)C903F7F"6D@!T$R)RDPQTD@A\DPQTD@!PDB)\$C!Z`)!B=1("<-,B<A,
MB>6)VTC![1M(,=A,(<!,,<A(`<A,B>%(P>$%2`GIB<E(`<A,B<%(P>$>B<5,
M">E-B>5)B>Z)R4GWU4G![AM)(=U((<I,">I,BVPD$$^-K"F9>8):3`'J28GM
M2<'E!4T)]46)[4P!ZDV)Y4G![`))P>4>08G630GL18GE28GL2??43"'H22',
M3`G@3(MD)!A*C9PCF7F"6DV)]$G![!M(`=A,B?-(P>,%3`GCB=M(`=A(B>M(
MP>T"2,'C'D&)Q$@)W8GK3(GU2/?52"':3"'M2`GJ2(ML)"!(C8PIF7F"6DR)
MY4C![1M(`<I,B>%(P>$%2`GIB<E(`<I,B?%)P>X"2,'A'HG520G.1(GQ38GF
M2??62"'(22'>3`GP3(MT)"A/C:PUF7F"6DF)[DG![AM,`>A)B>U)P>4%30GU
M18GM3`'H38GE2<'E'DG![`)!B<9-">Q%B>5)B>Q)]]1,(>I)(<Q,">),BV0D
M,$J-G".9>8):38GT2<'L&T@!VDR)\TC!XP5,">.)VT@!VDB)ZTC![0)(P>,>
M08G42`G=B>M,B?5(]]5((=A,(>U(">A(BVPD.$B-C"F9>8):3(GE2,'M&T@!
MR$R)X4C!X05(">F)R4@!R$R)\4G![@)(P>$>B<5)"<Y$B?%-B>9)]]9((<I)
M(=Y,"?),BW0D0$^-K#69>8):28GN2<'N&TP!ZDF)[4G!Y05-"?5%B>U,`>I-
MB>5)P>4>2<'L`D&)UDT)[$6)Y4F)[$GWU$PAZ$DAS$P)X$R+9"1(2HV<(YEY
M@EI-B?1)P>P;2`'83(GS2,'C!4P)XXG;2`'82(GK2,'M`DC!XQY!B<1("=V)
MZTR)]4CWU4@AVDPA[4@)ZDB+;"102(V,*9EY@EI,B>5(P>T;2`'*3(GA2,'A
M!4@)Z8G)2`'*3(GQ2<'N`DC!X1Z)U4D)SD2)\4V)YDGWUD@AR$DAWDP)\$R+
M="183XVL-9EY@EI)B>Y)P>X;3`'H28GM2<'E!4T)]46)[4P!Z$V)Y4G![`))
MP>4>08G&30GL18GE28GL2??43"'J22',3`GB3(MD)&!*C9PCF7F"6DV)]$G!
M[!M(`=I,B?-(P>,%3`GCB=M(`=I(B>M(P>T"2,'C'D&)U$@)W8GK3(GU2/?5
M2"'83"'M2`GH2(ML)&A(C8PIF7F"6DR)Y4C![1M(`<A,B>%(P>$%2`GI3(GU
M2<'N`DC!Y1Z)R4D)[D@!R$2)]4V)YHG!2??62"'J22'>3`GR3(MT)'!/C:PU
MF7F"6DF)SDG![AM,`>I)B<U)P>4%30GU18GM3`'J38GE2<'L`DG!Y1Y!B==-
M">Q%B>5)B<Q)]]1,(>A)(>Q,">!,BV0D>$J-G".9>8):38G\2<'L&T@!V$R)
M^TC!XP5,">.)VT@!V$B)RTC!Z0)(P>,>08G$2`G9B<M,B?E(]]%((=I,(>E(
M"<I(BXPD@````$B-C`V9>8):3(GE2,'M&T@!T4R)XDC!X@5(">I,B?U)P>\"
M2,'E'HG22`'120GO3(GB1(G]2/?208G.2"':2"'H2`G02(N4)(@```!)C905
MF7F"6DV)]4@!T$R)\DC!X@5)P>T;3`GJ38GE2<'L`DG!Y1Z)TDT)[$@!T$B+
ME"20````18GE38GT08G'2??43"'I22'L3`GA3(VD$YEY@EI,B?I(P>(%20',
M3(GY2,'I&T@)RHG220'43(GR2<'N`DC!XAY$B>-,"?)-B?Z)T4GWUDTA[D@A
MR$P)\$R+M"28````2HVL-9EY@EI)B=Y)P>X;2`'H2(G=2,'E!4P)]8GM2`'H
M3(G]2<'O`DC!Y1Y!B<9,"?U(,>I!,=1(BY0DH````$F-E!6AZ]EN38GU3`'B
M38GT2<'D!4G![1M-">Q%B>1,`>))B=Q(P>L"2<'D'D&)U4D)W$B)ZXGM3#'C
M2`.L)+`````QV$B+G"2H````2(V<&:'KV6Y,B>E(P>D;2`'#3(GH2,'@!4@)
MR(G`2`'#3(GP2<'N`DC!X!Z)V4P)\$V)YD6)Y$DQQDP#I"2X````1#'R3(V\
M%:'KV6Y(B<I(B<U(P>T;2,'B!4@)ZDR)[4G![0)(P>4>B=),">U)B<5)`==)
M,>U$B?J)P$0QZTV-K!RAZ]EN2(G328G42<'L&TC!XP5,">.)VTD!W4B)RT@#
MA"3`````2,'I`DC!XQY%B>Y("<M(B>E-B?1(,=E)P>P;03'/2HV,.*'KV6Y,
MB?!(P>`%3`G@B<!(`<A(B=%(P>H"2,'A'D&)Q$@)T8GJ2`.4),@```!(B=V)
MVT@#G"30````2#'-03'M2HVL*J'KV6Y,B>)-B>5)P>T;2,'B!4P)ZHG22`'5
M3(GR2<'N`DC!XAY!B>U,"?))B<Z)R4DQUD0Q\$V)[DB-G`.AZ]EN3(GH2<'N
M&TC!X`5,"?")P$@!PTR)X$C!X!Y)P>P"2`.,)-@```!,">!)B=1!B=Y),<2)
MTD@#E"3@````1#'E38GT2(VL*:'KV6Y,B?%)P>P;2,'A!4P)X8G)2`'I3(GM
M2<'M`DC!Y1Y!B<Q,">U)B<6)P$DQ[4@#A"3H````1#'K38GE2(V<&J'KV6Y,
MB>))P>T;2,'B!4P)ZHG22`':3(GS2<'N`DC!XQY!B=5,"?-)B>Z)[4DQWD0Q
M\4V)[DB-C`BAZ]EN3(GH2<'N&TC!X`5,"?")P$@!R$R)X4G![`)(P>$>08G&
M3`GA2`.L)/````!)B=Q),<R)VT@#G"3X````1#'B38GT2<'L&TB-K!6AZ]EN
M3(GR2,'B!4P)XHG22`'53(GJ2<'M`DC!XAY!B>Q,">I)B<V)R4DQU4@#C"0`
M`0``1#'H38GE2(V<`Z'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'#3(GP2<'N`DC!
MX!Y!B=U,"?!)B=:)TDDQQD@#E"0(`0``1#'U38GN2(VL*:'KV6Y,B>E)P>X;
M2,'A!4P)\8G)2`'I3(GE2<'L`DC!Y1Y!B<Y,">5)B<2)P$DQ[$0QXTV)]$@#
MA"00`0``2(V<&J'KV6Y,B?))P>P;2,'B!4P)XHG22`':3(GK2<'M`DC!XQY!
MB=1,">M)B>V)[4DQW4@#K"08`0``1#'I38GE2(V,"*'KV6Y,B>!)P>T;2,'@
M!4P)Z(G`2`'(3(GQ2<'N`DC!X1Y!B<5,"?%)B=Z)VTDQSD@#G"0@`0``1#'R
M3(VT%:'KV6Y,B>I,B>U(P>T;2,'B!4@)ZHG220'63(GB2<'L`DC!XAY$B?5,
M">))B<R)R4DQU$0QX$F)[$B-G`.AZ]EN2(GH2,'@!4G![!M(`XPD*`$``$P)
MX(G`2`'#3(GH2<'M`DC!X!Y!B=Q,">A)B=6)TDDQQ4@#E"0P`0``13'N3HVL
M,:'KV6Y,B>%-B>9)P>X;2,'A!4P)\8G)20'-2(GI2,'M`DC!X1Y%B>](">E(
MB<6)P$@QS4@#A"0X`0``,>M,B?U(C9P:H>O9;DR)^DC![1M(P>(%2`GJ3(GE
M2<'L`DC!Y1Z)TDP)Y4F)S$@!VDDQ[(G3B<E%,>5)B=Q.C;0HH>O9;DB)V$G!
M[!M(P>`%3`G@38G\B<!)`<9)P>\"2<'D'DT)_$B)Z$6)]4P)X$@APDB)Z(GM
M3"'@"<*XW+P;CTF)QTP#O"1``0``3`'Y38GO2`'*3(GI2<'O&TC!X05,"?F)
MR4@!RDB)V4C!ZP)(P>$>08G72`G93(GC2`G+22'>3(GC18GD2"'+00G>2(G#
M2`.<)$@!``!(`=U,B?M)`>Y,B?U(P>,%2,'M&T@)ZXG;28TL'DR)ZTG![0)(
MP>,>3`GK28G-08GN20G=3"'J28G-B<E)(=U$">I)B<5,`ZPD4`$``$T![$V)
M]4D!U$R)\DG![1M(P>(%3`GJB=)-C2P43(GZ2<'O`DC!XAY,"?I)B=]%B>Q)
M"==,(?U)B=^)VTDAUT0)_4F)QTP#O"18`0``3`'Y38GG2`'-3(GA2<'O&TC!
MX05,"?F)R4R-?`T`3(GQ2<'N`DC!X1Y,"?%)B=9$B?U)"<Y-(?5)B=:)TDDA
MSD4)]4F)QDP#M"1@`0``3`'S38UT'0!(B>M)B>U(P>,%2<'M&TP)ZXG;38TL
M'DR)XTG![`)(P>,>20G<2(G+18GN3`GC22'?2(G+B<E,(>-!"=](B<-(`YPD
M:`$``$@!VDR)\TD!UTR)\DC!ZQM(P>(%2`G:B=))C1P72(GJ2,'M`DC!XAY(
M"=5,B>)!B=](">I)(=5,B>)%B>1((>I!"=5(B<)(`Y0D<`$``$@!T4R)^DP!
MZ4V)_4C!X@5)P>T;3`GJB=),C2P13(GR2<'N`DC!XAY,"?))B>Y$B>E)"=9,
M(?-)B>Z)[4DAUD0)\TF)QDP#M"1X`0``30'T28G.20'<2(G+2<'N&TC!XP5,
M"?.)VTV--!Q,B?M)P>\"2,'C'DP)^TF)UT6)]$D)WTTA_4F)UXG222'?10G]
M28G'3`.\)(`!``!,`?U-C7PM`$R)Y4V)Y4G![1M(P>4%3`GMB>U-C2PO2(G-
M2,'I`DC!Y1Y(">E(B=U%B>]("<U)(>Y(B=V)VT@AS4$)[DB)Q4@#K"2(`0``
M2`'J3(G]20'63(GZ2,'B!4C![1M(">J)TDF-+!9,B>))P>P"2,'B'DD)U$B)
MRD&)[DP)XDDAU4B)RHG)3"'B00G52(G"2`.4))`!``!(`=-,B?),`>M-B?5(
MP>(%2<'M&TP)ZHG23(TL$TR)^DG![P)(P>(>3`GZ38GG1(GK20G73"']38GG
M18GD22'71`G]28G'3`.\))@!``!,`?E)B=](`<U(B=E)P>\;2,'A!4P)^8G)
M3(U\#0!,B?5)P>X"2,'E'DP)]4F)UD2)^4D)[DTA]4F)UHG222'N10GU28G&
M3`.T)*`!``!-`?1)B<Y-`>5)B<Q)P>X;2<'D!4T)]$6)Y$^-="4`28G<2,'K
M`DG!Y!Y,">-)B>Q%B?5)"=Q-(>=)B>R)[4DAW$4)YTF)Q$P#I"2H`0``3`'B
M38GL20'73(GJ2<'L&TC!X@5,">*)TDV-)!=(B<I(P>D"2,'B'D@)T4B)VD6)
MYT@)RDDAUDB)VHG;2"'*00G62(G"2`.4)+`!``!(`=5,B?I)`>Y,B?U(P>(%
M2,'M&T@)ZHG228TL%DR)ZDG![0)(P>(>3`GJ28G-08GN20G532'L28G-B<E)
M(=5%">Q)B<5,`ZPDN`$``$P!ZTV)]4D!W$R)\TG![1M(P>,%3`GKB=M,`>--
MB?Q)P>\"2<'D'D&)W4T)_$F)UTT)YTPA_4F)UXG232'G1`G]28G'3`.\),`!
M``!,`?E,C7P-`$R)Z4R)[4C![1M(P>$%2`GIB<E)C2P/3(GQ2<'N`DC!X1Y)
M"<Y,B>%!B>],"?%((<M,B>%%B>1,(?$)RTB)P4@#C"3(`0``2`'*2(T,$TR)
M^DR)^TC!ZQM(P>(%2`G:B=)(C1P13(GI2<'M`DC!X1Y,">E-B?6)VDD)S4PA
M[4V)]46)]DDAS40)[4F)Q4P#K"30`0``2`.$)-@!``!-`>Q.C6PE`$B)U4F)
MU$G![!M(P>4%3`'P3`GEB>U-C60M`$R)_4G![P)(P>4>3`G]28G/18GE20GO
M38GN3"'[28G/B<E)(>]$"?M(`=A,B>M(P>,%2<'N&TP)\XG;2`'82(G32,'J
M`DC!XQY!B<9("=.ZUL%BRDF)UTP#O"3@`0``20'/2(GIB>U(,=E!,<Q+C0PG
M38GT38GW2<'O&TG!Y`5-"?Q%B>1,`>%-B>Q)P>T"2<'D'D&)STT)[$F)U4P#
MK"3H`0``3`'M28G=B=M-,>5$,>A-B?U(`>A,B?U)P>T;2,'E!4P)[8GM2`'H
M3(GU2<'N`DC!Y1Y!B<5,"?5)B=9,`[0D\`$``$P!\TV)YD6)Y$DQ[D0Q\4V)
M[D@!V4R)ZTG![AM(P>,%3`GSB=M(`=E,B?M)P>\"2,'C'D&)SDP)^TF)UTP#
MO"3X`0``30'\28GOB>U),=]$,?A-B?=,`>!-B?1)P>\;2<'D!4T)_$6)Y$P!
MX$V)[$G![0))P>0>08G'30GL28G53`.L)``"``!,`>U)B=V)VTTQY40QZ4V)
M_4@!Z4R)_4G![1M(P>4%3`GMB>U(`>E,B?5)P>X"2,'E'D&)S4P)]4F)UDP#
MM"0(`@``3`'S38GF18GD23'N1#'P38GN2`'83(GK2<'N&TC!XP5,"?.)VT@!
MV$R)^TG![P)(P>,>08G&3`G[28G73`.\)!`"``!-`?Q)B>^)[4DQWT0Q^4V)
M]TP!X4V)]$G![QM)P>0%30G\18GD3`'A38GL2<'M`DG!Y!Y!B<]-">Q)B=5,
M`ZPD&`(``$P![4F)W8G;33'E1#'H38G]2`'H3(G]2<'M&TC!Y05,">V)[4@!
MZ$R)]4G![@)(P>4>08G%3`GU28G63`.T)"`"``!,`?--B>9%B>1),>Y$,?%-
MB>Y(`=E,B>M)P>X;2,'C!4P)\XG;2`'93(G[2<'O`DC!XQY!B<Y,"?M)B==,
M`[PD*`(``$T!_$F)[XGM23'?1#'X38GW3`'@38GT2<'O&TG!Y`5-"?Q%B>1,
M`>!-B>Q)P>T"2<'D'D&)QTT)[$F)U4P#K"0P`@``3`'M28G=B=M-,>5$,>E-
MB?U(`>E,B?U)P>T;2,'E!4P)[8GM2`'I3(GU2<'N`DC!Y1Y!B<U,"?5)B=9,
M`[0D.`(``$P!\TV)YD6)Y$DQ[D0Q\$V)[D@!V$R)ZTG![AM(P>,%3`GSB=M(
M`=A,B?M)P>\"2,'C'D&)QDP)^TF)UTP#O"1``@``30'\28GOB>U),=]$,?E-
MB?=,`>%-B?1)P>\;2<'D!4T)_$6)Y$P!X4V)[$G![0))P>0>08G/30GL28G5
M3`.L)$@"``!,`>U)B=V)VTTQY40QZ$V)_4@!Z$R)_4G![1M(P>4%3`GMB>U(
M`>A,B?5)P>X"2,'E'D&)Q4P)]4F)UDP#M"10`@``3`'S38GF18GD23'N1#'Q
M38GN2`'93(GK2<'N&TC!XP5,"?.)VT@!V4R)^TG![P)(P>,>08G.3`G[28G7
M3`.\)%@"``!-`?Q)B>^)[4DQWT0Q^$V)]TP!X$V)]$G![QM)P>0%30G\18GD
M3`'@38GL2<'M`DG!Y!Y!B<=-">Q)B=5,`ZPD8`(``$P![4F)W8G;33'E1#'I
M38G]2`'I3(G]2<'M&TC!Y05,">U-B?5)P>X"2<'E'HGM30GU28G63`.T)&@"
M``!(`>F)S4P!\TV)YD6)Y$TQ[D0Q\$F)[D@!V$B)ZTG![AM(P>,%3`GSB=M(
M`=A,B?M)P>\"2,'C'D&)QDP)^TF)UTP#O"1P`@``30'\38GO18GM23'?1#'Y
M38GW2`.4)'@"``!)`<Q,B?%)P>\;2,'A!4$!VTP)^4R)7R!!`<Q(B>E(P>T"
M2,'A'DP!ZDF)W4@)Z4R)]4G![@)),<U(P>4>1`'F1#'H38GE3`GU2`'03(GB
M2<'M&TC!X@5!`>E$`=%,">I(B7<(3(E/$`'02(E/&$$!P$B+A"2(`@``9$@S
M!"4H````3(D'=1)(@<28`@``6UU!7$%=05Y!7\/HBN+__V8N#Q^$``````!!
M5T%6055!5%532(/L"$B%_P^$HP```$R+/0IW(`!-A?\/A),````/M@>$P'1R
M/#UT;DF)_$F#Q`%!#[8$)(3`=`0\/77O02G\28L?2(7;=#5)B?5)B?Y-8^1,
MB?T/'P!,B>),B?9(B=_H4N'__X7`=0="@#PC/70O2(/%"$B+70!(A=MUVDB#
MQ`A(B=A;74%<05U!7D%?PP\?A```````13'DZZ0/'P!,*?U*C5PC`4C!_0-!
MB6T`Z\PQV^O(9I!54TB)_4B#[!AD2(L$)2@```!(B40D"#'`2(U<)`1FD#'`
M2(G>2(GOZ!/___](A<!T,$AC5"0$2(L%*G8@`$B-!-!(BU`(2(722(D0=-)F
MD$B#P`A(BU`(2(722(D0=?#KODB+1"0(9$@S!"4H````=0=(@\086UW#Z$+A
M__]FD$%7059!54%455-(B?-(B?U(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]
M#Y3`2`'#2(G?Z/G@__](C70D%$F)Q$B)[S'`Z'?^__](A<`/A`X!``!(B<=)
MB<7HT^#__TDYQ`^&X@```$QC="042<'F`P^V10"$P`^$JP$``#P]#X2C`0``
M2(GHZPT/'X0``````(#Z/70+2(/``0^V$(32=?!(*>A(F$P#-3QU(`!*C7P@
M`NC*X?__2(7`28D&#X1X`0``2&-4)!1(BP4:=2``2(U-`4B+%-`/MD4`/#V(
M`G0FA,!U$.L@9BX/'X0``````#P]=!)(@\$!#[9!_TB#P@&$P(@"=>K&`CTQ
MP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`2(MT)!AD2#,T)2@````/A0X!``!(
M@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#_TF#Q0&$P$&(1?]U[.O"9I!,BSV!
M="``28,_``^$O````$R)^#'2ZPL/'X0``````$2)ZDB#P`A$C6H!2(,X`'7O
MC7(#2&/V2,'F`XL%?X0@`(7`=#M,B?_H8^'__TB%P$B)!3%T(``/A'T```!-
M8\5(B<%.C33%`````$K'1,$(`````$2);"04Z9'^__]FD$B)]\<%,X0@``$`
M``#HCN#__TB%P'1#36/%3(G^2(G'3HTTQ0````!,B40D"$R)\N@;X?__3(M$
M)`A(B<%(B07$<R``ZZ4QP.EX_O__OA````!%,>WI8?___[C_____Z=[^___H
M]][__P\?@`````!!5D%505154TB![*````!D2(L$)2@```!(B80DF````#'`
M2(7_=`B`/P!(B?UU,4B+A"28````9$@S!"4H````#X4Q`0``2('$H````%M=
M05Q!74%>PV8N#Q^$``````#H*][__TB%P$F)Q'3"28GE3(GGZ'C@__](A<!(
MB<-T-0^V4Q.X+@```(G!*=%U00^V4Q2%TG39*=`/A,$```#WV(7`=2],B>?H
M0^#__TB%P$B)PW7+3(GGZ+/>__](B>_H"][__^EE____9@\?1```A<ETG$B#
MPQ-(B>_H`-[__TB)WTF)QNCUW?__08U\!@)(8__H.-___TB-#?4;``!)B<9(
MB<=)B=E)B>A(Q\+_____O@$````QP.B"X/__OP$```!,B>I,B?;H4MW__X/X
M_TR)]W00BT0D&"4`\```/0!```!T*NC5W/__3(GWZ*W<___I&/___P\?A```
M````#[9#%>DX____#Q^``````.B+_O__Z]3H=-W__P\?0`!32(G[BSWF<2``
MZ)'>__](C9```@``2(G>OP$```#HK=___X7`=`DQP%O##Q]$``"+/;IQ(`#H
M9=[__XN`&`(``"4`\```/0!```!T'8L]G7$@`.A(WO__BX`8`@``)0#P```]
M`*```'6]2(G?O@(```#H&=___X7`#Y3`#[;`6\,/'T0``&8N#Q^$``````!!
M54%428G\55-(C3W:&@``28GUNO\/``!(@>P8$```2(GF9$B+!"4H````2(F$
M)`@0```QP.@&W/__A<!^<HU0_TB)XTACZH`\+`!T6TACZ$B)ZKXO````2(G?
MZ$#=__](A<!T2XL]]7`@`.B@W?__2(GI2(G:3(GF2(G'Z)_>__](BX0D"!``
M`&1(,P0E*````'4W2('$&!```%M=05Q!7<-F#Q]$``"%TG6D#Q]``(L]JG`@
M`.A5W?__3(GJ3(GF2(G'Z%?<___KMN@0W/__2(/L"(L]AG`@`.@QW?__2(L5
M&G`@`$B-#1L<``!(C34%&@``2(G'2(/$".E0W?__2(/L"(L]5G`@`.@!W?__
M2(G'Z+G___^+/4-P(`#H[MS__TR-!9`;``!(C170%```2(TUWAD``$4QR4B)
MQTB#Q`A,B<'I5]W__P\?@`````!54TB!["@@``!D2(L$)2@```!(B80D&"``
M`#'`Z._:__],C0U]&0``2(T-JQD``$&)P+H!$```,<"^`0```$B)Y^CZW?__
MA<!X;DB-K"00$```N@`0``!(B>=(B>[HCMK__X7`2(G#>$^->`%(8__H7-S_
M_TB%P$B)P7082&/;2(GN2(G'2(G:Z!/<__](B<'&!!@`2(N4)!@@``!D2#,4
M)2@```!(B<AU$DB!Q"@@``!;7<,/'T``,<GKV.C/VO__#Q]$``!F+@\?A```
M````Z2O___^09BX/'X0``````$%7059!54%428GT55-(B?M(C3WQ&```2('L
M*!```&1(BP0E*````$B)A"08$```,<!(C70D#.CU]___OB\```!(B=](B<7H
MA=K__TB%P'0]2(T]NA@``$B)WC'`Z`_Y__](B=A(BXPD&!```&1(,PPE*```
M``^%B0$``$B!Q"@0``!;74%<05U!7D%?PTB)W^@+VO__2(TU@A@``$R)YT&)
MQN@YW/__2(7`28G'=*%!@\8!08`_`$R-+6`8``!,C60D$`^$Y0````\?@```
M``!(A>UT$TR)_DB)[^BPVO__A<`/A*8```!,B?_HL-G__XG"2)A!@'P'_R]U
M%P\?0`"#Z@%(8\)!@'P'_R]!Q@0'`'3M1`'R@?K_#P``#X\N____2(/L"$B-
M#1(9``!,C0WL%P``4TV)^+H`$```O@$```!,B><QP.@4W/__BSW>;2``Z(G:
M__](C9```@``3(GFOP$```#HU=C__X7`6EEU'8L]N6T@`.ADVO__BX`8`@``
M)0#P```]`(```'1),?],B>[H2-O__TB%P$F)QP^$K/[__T&`/P`/A2+___](
MA>UT$TB-/4P7``"Y`@```$B)[O.F=,A,C3TY%P``N@$```#I//___[X!````
M3(GGZ.S:__^%P'6F2(T](A<``$R)YNAY]___3(GGZ%'9___I8/[__^BGV/__
M#Q^```````^V#TB)^(3)=!A(C5<!9I"`^2\/M@I(#T3"2(/"`83)=>[SPV:0
M9BX/'X0``````%532(/L"$B%_W15#[8O2(G[0(3M=$KH1=C__TB-5`/_2#G3
M<A3K)V8/'X0``````$B#Z@%(.=-T'X`Z+W3RZP6`.B]T0$B#Z@%(.=-R\D@Y
MTW4R#Q]$``!`@/TO=7-FD+\"````Z$;9__](A<!T6;HN````9HD02(/$"%M=
MPV:0@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`$```=RM(C3VL;"``2(G>2(/"
M`;D`$```Z%O9__](@\0(2(T%D&P@`%M=PP\?1```2(/$"#'`6UW#2(/$"$B-
M/006``!;7>DMV/__#Q\`9BX/'X0``````%-(C3WJ%0``2(/L0&1(BP0E*```
M`$B)1"0X,<!(BP5=%P``2(U<)`Q(B40D$$B+!507``!(B40D&$B+!5`7``!(
MB40D($B+!4P7``!(B40D*`^W!4@7``!FB40D,#'`Z%SU__](C3V0%0``,<#H
M3O7__TB-/8H5```QP.A`]?__2(T]A14``#'`Z#+U__](C3U^%0``,<#H)/7_
M_TB-/8`5```QP.@6]?__2(T])Q4``#'`Z`CU__](C3UP%0``,<#H^O3__TB-
M/6P5```QP.CL]/__2(T]:!4``#'`Z-[T__](C3WX%```,<#HT/3__TB-/585
M```QP.C"]/__2(T]414``#'`Z+3T__](C3U.%0``,<!(B=[HX_/__TB%P'01
M2(T]$!4``$B)QC'`Z`WU__](C3TX%0``,<!(B=[HO//__TB%P'012(T]-!4`
M`$B)QC'`Z.;T__](C3TN%0``,<!(B=[HE?/__TB%P'1`2(T]810``$B)QC'`
MZ+_T__](C34S%0``2(T]A!0``#'`Z*KT__](BT0D.&1(,P0E*````'5G2(/$
M0%O##Q]``$B-/>@4```QP$B)WN@_\___2(7`=!I(C3UB%```2(G&,<#H:?3_
M_^NH#Q^``````$B-="0A2(T]Q!0``+D*````\Z9UC$B-="0K2(T]+A0``#'`
MZ#CT___I=/___^ANU?__#Q]``&8N#Q^$``````!(@^P89$B+!"4H````2(E$
M)`@QP(L%MFD@`(/X_W092(M,)`AD2#,,)2@```!U14B#Q!C##Q]``$B-="0$
M2(T]RQ,``#'`Z)7R__](A<!T(`^V$(#Z,`^5P(32#Y7"(=`/ML")!6=I(`#K
MM`\?1```,<#K[.CGU/__#Q^``````$B#[`CHY]3__XG'Z)#4__](A<!T"TB+
M`$B#Q`C##Q\`,<#K]&:09BX/'X0``````$%7059!54%428G]55-(C2WC$P``
M2(T=TA,``$B#[&AD2(L$)2@```!(B40D6#'`2(T%Q!,``$B);"0@2(E<)"A(
MQT0D4`````!,C60D($R-="0<2(E$)#!(C061$P``2(E$)#A(C06*$P``2(E$
M)$!(C060$P``2(E$)$CK(&:02(G'Z,C6__](A<!T:TF#Q`A(A=MT.$B)W4F+
M7"0(3(GV,<!(B>_HA?'__TB%P$F)QTR)[G0%@#@`=<4QP$B)[TF#Q`CHI_+_
M_TB%VW7(2(M$)%AD2#,$)2@````/A84```!(@\1H6UU!7$%=05Y!7\,/'X``
M````3(GOZ*#3__],B?](B40D".B3T___2(M,)`A(C7P!`NC4U/__2(/L"$R-
M#?<1``!(C0T1$P``05=(Q\+_____2(G'38GHO@$```!(B40D&#'`Z!+6__],
MBU0D&$B)[S'`3(G6Z!#R__]86NDF____Z$33__\/'T``05=!5D%5051)B?U5
M4TB-/801``!(@>R(@0``9$B+!"4H````2(F$)'B!```QP$B-!7D2``!,C60D
M+$C'1"1``````$C'A"28`````````$C'1"1@`````$B)1"0P2(T%,A$``$R)
MYDB)1"0X2(T%T1$``$B)1"1P2(T%OA$``$B)1"1X2(T%*!(``$B)A"2`````
M2(T%P!$``$B)A"2(````2(T%$A(``$B)A"20````2(T%ZA$``$B)1"102(T%
M^Q$``$B)1"18,<#H\.___TB%P'0)@#@`#X5B!```,<#H>_W__TB%P$B)PP^$
M;P0``$B)W^@WTO__2(U\``'H?=/__X`[`$F)QG0W3(T]MA$``$R)]0\?`$0/
MM@-(B>\QP$R)^4C'PO____^^`0```$B#PP%(@\4"Z+/4__^`.P!UUDB-;"1P
M2(T]]A```.L-2(/%"$B+?0!(A?]T,S'`3(GFZ%GO__](A<!(B<-TX8`X`'3<
M2(G'Z%3T__^%P'302(G?Z%C2__](A<!)B<=U4$B+7"0P,>WK&P\?@`````"#
MQ0%(8\5(BUS$,$B%VP^$3`$``(`[``^$0P$``$B)W^@+]/__A<!TUTB)W^@/
MTO__2(7`28G'=,</'X``````3(G_Z$C1__],B?&+,4B#P02-EO_^_O[WUB'R
M@>*`@("`=.B)UL'N$/?"@(````]$UDB-<0)(#T3.B=9``-9(@]D#3"GQC9P(
M!`0``$ACVTB)W^A)TO__2(G%2(T%E1```$%63(T-9@\``$B-#7P0``!-B?A0
M2,?"_____[X!````2(GO,<#HA=/__[[``0``2(GOZ!C0__^#^/]!6$%9#X2+
M````BSTU92``Z.#1__](C9```@``2(GNOP$```#H_-+__X7`08G&#X2A````
M28M-`$B+/49E(`!(C17W$```28GHO@$````QP#';Z/[2__](BXPD>($``&1(
M,PPE*````$B)V`^%8PD``$B!Q(B!``!;74%<05U!7D%?PV:013'_Z=C^__\/
M'X0``````.A+S___1(L(08/Y$0^$8____TF+30!(BSW39"``2(T51!```$F)
MZ+X!````,<`QV^B+TO__ZXMF#Q^$``````"+/6ID(`#H%='__XN`&`(``"4`
M\```/0!````/A3[___^+/4ED(`#H]-#__T2+N!P"``#HR,___T$YQP^%'O__
M_XL]*60@`.C4T/__BX`8`@``)?\!```]P`$```^%_?[__TB)W^C&T/__2(T]
MOPX``$B)PTR)YC'`Z/+L__](A<`/A/$!``!(B<?H`=#__TF+?0!(B<;HI?3_
M_TB%P$F)Q`^$T0$``$R)Y^@QS___@_@#?CQ(8]!(C3W-#@``N04```!)C704
M_/.F=22#^`0/A-<&``"#Z`1(F$&`?`3_+P^$Q@8``&8N#Q^$```````QP.B9
M^?__A<!U%3'V3(GGZ,O0__^%P(D$)`^%<0$``$B--10.``!(C3V!#0``3(TE
MI`X``#'`3(TM,@T``.A][?__Z#C.__]!5$R-#1\-``!02(T-6PX``$C'PO__
M__])B>B^`0```$B)WS'`Z#[1__]86NM-9BX/'X0``````.B;S?__@S@1=4OH
M\<W__T&#Q@%(@^P(2(T-)`X``$%4059-B>E028GH2,?"_____[X!````2(G?
M,<#H\=#__TB#Q""^P`$``$B)W^B`S?__@_C_=*M(B>_H,\W__TB-/70,``!(
MB=XQP.C2[/__2(G?Z%KY___IE_W__P\?1```2(G'2(D$).A$^?__2(L$)$B)
MQ^B(SO__2(G#Z7+]__^]`0```$B-/38-``#K$F:02&/%@\4!2(M\Q%!(A?]T
M*3'`3(GFZ#;K__](A<!TX8`X`'3<2(G'Z$3.__](A<!(B<-TS.E(^___OPT`
M``!(C1WR#```Z,;.__])B<;I2?O__V8/'T0``$V+90#I)O[__TR-M"1P`0``
MN@(```!(Q\;N____08G'B<?HT<___[H&````3(GV1(G_Z!'.__^`O"1P`0``
M`'4.@+PD<0$``$,/A*8%``"+/"0QTC'V3(VL)*````#HE<___[B)J\WO2,>$
M)*`````!(T5G2,>$)+@```!V5#(02(F$)*@```"X_MRZF$C'A"3(````````
M`$B)A"2P````N/#ATL-(QX0DT`````````!(B80DP````$F-13C'A"08`0``
M`````$B)1"009BX/'X0``````(L\)+H`@```3(GVZ&#-__^%P$F)Q$&)P`^.
MLP$``$B+M"3(````26/$C13&2#G6#X>+`0``2(NT)-````!(P>@=2(F4),@`
M``!(`?!(B80DT````$ACA"08`0``A<`/A$P!``!!N$````!(BU0D$$R)]D$I
MP$4YQ$4/3L1(C3P"26/(2(G*28G/2(E,)`CH'<W__XN$)!@!``!$`?B#^$")
MA"08`0``#X53____18G@3(GO12GX3(M\)`A$B40D'.@+TO__1(M$)!Q-`?</
M'P!!@_@_#XZE````08U`P(E$)!S!Z`9!B<2)1"0(28/$`4G!Y`9-`?QF#Q^$
M``````!)BP=,B>])@\=`2(F$)-@```!)BT?(2(F$).````!)BT?02(F$).@`
M``!)BT?82(F$)/````!)BT?@2(F$)/@```!)BT?H2(F$)``!``!)BT?P2(F$
M)`@!``!)BT?X2(F$)!`!``#H9='__TTY_'60BT0D"$2+1"0<P>`&02G`2(M\
M)!!)8]"Y2````$R)_D2)1"0(Z`?,__]$BT0D"$2)A"08`0``Z57^__\/'T0`
M`$V)]^D8____#Q^$``````!(BXPDT````$B-<0'I;/[__XL\).@WR___3(ND
M),@```!,B[0DT````$R)X$C!Z`.#X#^-4`%(F,:$!-@```"`@_HX#X^.`@``
MN#@````IT$ACTH/X"$F-5!4X#X.V`@``J`0/A6<#``"%P'0+J`+&`@`/A6L#
M``!,B?!,B>]$B+0D$P$``$C!Z!A$B*0D%P$``$R-O"0A`0``B(0D$`$``$R)
M\$R-+;T)``!(P>@0B(0D$0$``$R)\$R-M"1H`0``2,'H"(B$)!(!``!,B>!(
MP>@8B(0D%`$``$R)X$C!Z!"(A"05`0``3(G@2,'H"(B$)!8!``#H%=#__TB+
MA"2@````2(G"B(0D(P$``$C!ZAA$#[;"B)0D(`$``$B)PDC!ZA"(E"0A`0``
M2(G"2(N$)*@```!(P>H(B)0D(@$``$B)PHB$)"<!``!(P>H8B)0D)`$``$B)
MPDC!ZA"(E"0E`0``2(G"2(N$)+````!(P>H(B)0D)@$``$B)PHB$)"L!``!(
MP>H8B)0D*`$``$B)PDC!ZA"(E"0I`0``2(G"2(N$)+@```!(P>H(B)0D*@$`
M`$B)PHB$)"\!``!(P>H8B)0D+`$``$B)PDC!ZA"(E"0M`0``2(G"2(N$),``
M``!(P>H(B)0D+@$``$B)PHB$)#,!``!(P>H8B)0D,`$``$B)PDC!ZA"(E"0Q
M`0``2(G"2(V$)$`!``!(P>H(B)0D,@$``$B)!"1)B<3I"````$4/M@=)@\<!
M3(GG,<!,B>E(Q\+_____O@$```!)@\0"Z#O+__]-.>9UUDB-!5@(``#&A"1H
M`0```%#_="0(2(T-$`@``$R-#=0&``"^`0```$F)Z$C'PO____](B=\QP.C[
MRO__65[I&?K__TV+;0A-A>T/A#?Y__],B>_H'\C__TB#^`,/AB7Y__])C70%
M_$B-/;D'``"Y!0```/.F30]$Y>D)^?__N$````!(8\HIT$F-3`TXB<)T#S'`
MB<:#P`$YT,8$,0!R\TR)[^@/SO__28U5.+D'````,<!(B=?S2*OI8?W__XG!
M2,<"`````$C'1`KX`````$B-2@A(@^'X2"G*`="#X/B#^`@/@C;]__^#X/@Q
MTHG6@\((.<)(QP0Q`````'+OZ1O]__^`O"1R`0``00^%3/K__X"\)',!``!#
M#X4^^O__@+PD=`$``$@/A3#Z__^`O"1U`0``10^%(OK__T2+/"2Z`@```$C'
MQL;___]$B?_HL\G__[HI````3(GV1(G_Z//'__](C07U!@``4$%6Z:+^__\/
M'T``QP(`````QT0"_`````#IE?S__S'_9HE\`O[IB?S__^CLQO__9I!F+@\?
MA```````059!54%455-(@^P0BSU.6R``9$B+!"4H````2(E$)`@QP$R-;"0$
MZ.3'__^+/2Y;(`!(B</HUL?__P^V@+@```!(C3TK!0``3(GNB(.Y````,<#H
M".3__TB%P'0)@#@Q#X2J`@``,<#H\^[__XL][5H@`.B8Q___2(TU-`8``+D+
M````N@$```!(B<?H/\?__TB%P`^$MP```(,]+VL@``%(BT`03(M@*`^.H@``
M`#'MNP$```#K,P\?A```````28MV$$B+!?UJ(`!(8]-(BSS0Z.G&__^%P'5E
MBP7O:B``@\,!@\4!.=A^6XL];UH@`.@:Q___,<E(8]5,B>9(B<?HZL?__TB%
MP'0U3(LP08M&#"4`!"``/0`$``!THHL]/%H@`.CGQO__3(GVN0(````QTDB)
MQ^CUQ?__2(G&ZX2+!8IJ(`"-4/\YZ@^$?P$``(L]"5H@`.BTQO__2(TU504`
M`+D#````N@$```!(B<?H6\;__TB%P$B)PW0U2(M`$(L]V5D@`$B+*.B!QO__
M2(T5)`4``$B)QTB)[NA_Q?__2(M#$$B+&/9##D`/A<H!``"+/:A9(`#H4\;_
M_TB--?L#``"Y`P```+H!````2(G'Z/K%__](A<!(B<-T/4B-/5P#```QP$R)
M[NAQXO__2(7`2(G%#X15`0``2(M#$(L]6UD@`$B+&.@#QO__2(GJ2(G'2(G>
MZ`7%__^+/3]9(`#HZL7__TB--9($``"Z`0```$B)Q^CVQ?__BST@62``2(G#
MZ,C%__](C16%!```2(G>2(G'Z,;$__^+/0!9(`#HJ\7__TB-/<P"``#&@+D`
M````3(GN,<#HX^'__TB%P$B)PTB)!4YI(``/A)````"^P`$``$B)W^B3P___
MC5`!@_H!=@F#^!$/A>X```!(BT0D"&1(,P0E*`````^%U0```$B#Q!!;74%<
M05U!7L.0@_@!#XYX_O__NP$```!FD(L]>E@@`(/#`>@BQ?__3(GF2(G'Z%?#
M__\Y'=%H(`!_W^E+_O__9BX/'X0``````(!X`0`/A%/]___I1_W__Y!(BSVA
M:"``Z'3P__](A<!(B<-(B06?:"``#X51____2(T]:@0``#'`Z//$__\/'P!(
MBP5Q:"``BST#6"``2(LH2(M#$$B+&.BDQ/__2(GN2(G?Z(GF___IG_[__XL]
MWE<@`.B)Q/__2(G>2(G'Z-[$___I&_[__^A$P___B<%(BP4C:"``2(T]+`0`
M`$B)VDB+,#'`Z(?$__\/'X``````55-(B?U(@^P(Z*+J__\/M@B$R71.2(U0
M`4B)PP\?0`"`^2\/M@I(#T3:2(/"`83)=>XQP.B'[?__2(7M=!Z%P'0:@'T`
M`'042(TU9P(``$B)W^AIQ?__2#G8=`Q(@\0(6UW#2(G#Z\I(@\0(2(GO6UWI
MNN/__V8N#Q^$``````!(C04!5R``2(7`=`Q(BPCI',/__P\?0``QR>D1P___
MD$%7059!B?]!54%43(TE5E(@`%5(C2U64B``4TF)]DF)U4PIY4B#[`A(P?T#
MZ#?!__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!_Q3<2(/#`4@YW77J2(/$
M"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L"$B#Q`C#`````0`"`"5S
M+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0
M051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ5D524TE/3@`Q
M+C`S-@`M90`M+0!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I
M.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI
M<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2![
M"D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E
M('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%2
M7T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F
M<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@
M/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E
M="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q
M<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E
M860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<
M;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\
M("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U
M;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&
M2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B
M=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER
M95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[
M8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG
M+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N
M)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*```````!&P,[[````!P```#`@/__.`$``("$__]@`0``
MD(3__T0&``#`AO__"`$``/"'__]X`0``0)___\@!````H/__%`(``("@__]`
M`@``T*+__XP"``!0I/__T`(``."D___P`@``L*7__RP#``#@I?__1`,``#"F
M__]<`P```*?__X@#```0I___G`,``""I___\`P``4*G__Q`$``!`JO__7`0`
M`&"L__^`!```X*S__YP$```0K?__N`0``("N__\4!0``X+K__\P%``"@OO__
M$`8``""___]P!@``0+___X@&``"PO___T`8````````4``````````%Z4@`!
M>!`!&PP'")`!!Q`4````'````+"%__\K```````````````4``````````%Z
M4@`!>!`!&PP'")`!```D````'````(!____``P````X01@X82@\+=PB``#\:
M.RHS)"(`````%````$0````8@___"```````````````3````%P```!PAO__
M1A<```!"#A"/`D(.&(X#1@X@C01"#BB,!4,.,(8&00XX@P='#M`%`Q\7"@XX
M00XP00XH0@X@0@X80@X00@X(00L```!(````K````'"=__^^`````$(.$(\"
M0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)\"@XX1`XP00XH0@X@0@X8
M0@X00@X(20L`*````/@```#DG?__?@````!!#A"&`D$.&(,#1PXP`FT*#AA!
M#A!!#@A!"P!(````)`$``#B>__])`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9!#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+0````'`!
M```\H/__?`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!
M#BA!#B!"#AA"#A!"#@A+"P`<````M`$``'BA__^!`````$$.$(,":0H."$8+
M`E`."#@```#4`0``Z*'__]``````0@X0C0)"#AB,`T0.((8$00XH@P56#L`@
M`GP*#BA!#B!!#AA"#A!"#@A'"Q0````0`@``?*+__S``````1`X09PX(`!0`
M```H`@``E*+__TD`````1`X0?0X(`"@```!``@``S*+__\$`````00X0A@)!
M#AB#`T<.P$`"J`H.&$$.$$$."$4+$````&P"``!PH___!0````````!<````
M@`(``&RC__\)`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!U$.
MX"`"9`H..$$.,$$.*$(.($(.&$(.$$(."$$+`ID.Z"!/#O`@>0[H($$.X"``
M```0````X`(``!RE__\D`````````$@```#T`@``.*7__^,`````00X0A@)!
M#AB#`T0.(`)U"@X800X000X(0PMY"@X82`X000X(1@M$"@X80PX000X(00M$
M#AA(#A!!#@@@````0`,``-RE__\2`@```$$.$(,"2PY0`YX!"@X000X(10L8
M````9`,``-BG__]Y`````$0.(&\*#@A%"P``&````(`#```\J/__)`````!$
M#A!8"@X(1`L``%@```"<`P``4*C__VP!````0@X0CP)"#AB.`T(.((T$0@XH
MC`5$#C"&!D$..(,'4@Z@`0+'"@XX00XP00XH0@X@0@X80@X00@X(2`MH#J@!
M4`ZP`7$.J`%!#J`!M````/@#``!DJ?__5`P```!"#A"/`D(.&(X#0@X@C01"
M#BB,!40.,(8&00XX@P=.#L"#`@,H`@[(@P)2#M"#`F@.R(,"0@[`@P("=`H.
M.$$.,$$.*$(.($(.&$(.$$(."$,+`XH!#LB#`D@.T(,"80[(@P)!#L"#`F,.
MR(,"20[0@P)"#MB#`D0.X(,"70[`@P(#QP4.R(,"1`[0@P)H#LB#`D$.P(,"
M`RX!"@[(@P)"#M"#`DD+`$````"P!```#+7__[D#````0@X0C@)"#AB-`T(.
M((P$00XHA@5!#C"#!D0.0`.Z`@H.,$$.*$$.($(.&$(.$$(."$(+,````/0$
M``"(N/__=@````!!#A"&`D$.&(,#1PX@`E<*#AA!#A!!#@A!"TD.&$0.$$$.
M""@````H!0``1'[__R0"````00X0A@)!#AB#`T0.4`.T`0H.&$$.$$$."$$+
M%````%0%``"HN/__'P``````````````1````&P%``"PN/__90````!"#A"/
M`D(.&(X#10X@C01"#BB,!4@.,(8&2`XX@P=-#D!R#CA!#C!!#BA"#B!"#AA"
M#A!"#@@`$````+0%``#8N/__`@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*`A````````
M8"$```````````````````````````````````````````````````$`````
M`````0`````````!`````````-\!`````````0`````````N`@````````P`
M````````B!H````````-`````````)19````````&0````````"(JR``````
M`!L`````````"``````````:`````````)"K(```````'``````````(````
M`````/7^_V\`````F`(````````%`````````"`-````````!@````````"0
M`P````````H`````````WP0````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<``````````!4````````'`````````%`3````````
M"`````````"P`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````T!(```````#___]O``````(`
M````````\/__;P``````$@```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````+BK(```````````````````
M`````````+8:````````QAH```````#6&@```````.8:````````]AH`````
M```&&P```````!8;````````)AL````````V&P```````$8;````````5AL`
M``````!F&P```````'8;````````AAL```````"6&P```````*8;````````
MMAL```````#&&P```````-8;````````YAL```````#V&P````````8<````
M````%AP````````F'````````#8<````````1AP```````!6'````````&8<
M````````=AP```````"&'````````)8<````````IAP```````"V'```````
M`,8<````````UAP```````#F'````````/8<````````!AT````````6'0``
M`````"8=````````-AT```````!&'0```````%8=````````9AT```````!V
M'0```````(8=````````EAT```````"F'0```````+8=````````QAT`````
M``#6'0```````.8=````````]AT````````&'@```````!8>````````)AX`
M```````V'@```````$8>````````5AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````#@7````````$=#
M0SH@*%5B=6YT=2`V+C0N,"TR=6)U;G1U,2D@-BXT+C`@,C`Q-S`W,C0`1T-#
M.B`H56)U;G1U(#8N-"XP+3%U8G5N='4R*2`V+C0N,"`R,#$W,#<P-```+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1A=&$N<F5L+G)O`"YD
M>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M``L````!`````@`````````X`@```````#@"````````'```````````````
M``````$````````````````````3````!P````(`````````5`(```````!4
M`@```````"`````````````````````$````````````````````(0````<`
M```"`````````'0"````````=`(````````D````````````````````!```
M`````````````````#0```#V__]O`@````````"8`@```````)@"````````
M^``````````%``````````@````````````````````^````"P````(`````
M````D`,```````"0`P```````)`)````````!@````$````(`````````!@`
M````````1@````,````"`````````"`-````````(`T```````#?!```````
M`````````````0```````````````````$X```#___]O`@``````````$@``
M```````2````````S``````````%``````````(``````````@````````!;
M````_O__;P(`````````T!(```````#0$@```````(``````````!@````(`
M```(````````````````````:@````0````"`````````%`3````````4!,`
M``````"P`0````````4`````````"``````````8`````````'0````$````
M0@``````````%0`````````5````````B`4````````%````&`````@`````
M````&`````````!^`````0````8`````````B!H```````"(&@```````!<`
M```````````````````$````````````````````>0````$````&````````
M`*`:````````H!H```````#``P``````````````````$``````````0````
M`````(0````!````!@````````!@'@```````&`>````````"```````````
M``````````@`````````"`````````"-`````0````8`````````<!X`````
M``!P'@```````"([```````````````````0````````````````````DP``
M``$````&`````````)19````````E%D````````)````````````````````
M!````````````````````)D````!`````@````````"@60```````*!9````
M````0$````````````````````@```````````````````"A`````0````(`
M````````X)D```````#@F0```````.P````````````````````$````````
M````````````KP````$````"`````````-":````````T)H```````#X!0``
M````````````````"````````````````````+D````.`````P````````"(
MJR```````(BK````````"`````````````````````@`````````"```````
M``#%````#P````,`````````D*L@``````"0JP````````@`````````````
M```````(``````````@`````````T0````$````#`````````)BK(```````
MF*L````````(````````````````````"````````````````````-8````!
M`````P````````"@JR```````*"K````````$P```````````````````!``
M``````````````````#C````!@````,`````````N*L@``````"XJP``````
M`!`"````````!@`````````(`````````!``````````B`````$````#````
M`````,BM(```````R*T````````X`@``````````````````"``````````(
M`````````.P````!`````P``````````L"````````"P````````(```````
M``````````````@```````````````````#R````"`````,`````````(+`@
M```````@L````````(@0```````````````````@````````````````````
M]P````$````P````````````````````(+````````!8````````````````
M`````0`````````!``````````$````#`````````````````````````'BP
F``````````$```````````````````$`````````````````````
